/*===========================================================================
						Common JavaScript functions
  ===========================================================================*/

function _template()
{
	try
	{
	
	} catch(e) {
		errorMessage(e);
	}		
}
/******************************************************************************
						Common JavaScript functions - Database
 *****************************************************************************/
function db_openDatabase(database)
{
	var dbConnection = null;
	try
	{
		if(database)
		{
			infoMessage(5, "db_openDatabase(): started: " + database.path);

			var ios				= Components.classes["@mozilla.org/network/io-service;1"].getService(Components.interfaces.nsIIOService);
			var sUri			= "file:///" + database.path;
			var uri				= ios.newURI(sUri, "", null);
			var nsifile			= uri.QueryInterface(Components.interfaces.nsIFileURL).file;
			var storageService	= Components.classes["@mozilla.org/storage/service;1"].getService(Components.interfaces.mozIStorageService);

			infoMessage(5, "db_openDatabase(): db path " + nsifile.path);

			dbConnection		= storageService.openDatabase(nsifile);
			
			infoMessage(5, "db_openDatabase(): db '" + dbConnection.databaseFile.path + "'; ready? " + dbConnection.connectionReady);
		} else {
			errorMessage("db_openDatabase(): No valid path to a database given!");
		}
	}
	catch(e)
	{
		errorMessage(e);
	}
	return dbConnection;
}

function db_closeDatabase(dbConnection)
{
	try
	{
		dbConnection.asyncClose();
	}
	catch(e)
	{
		errorMessage(e);
	}
}

function db_executeStatement(dbConnection, sql, fCompletion, oResultHandle)
{
	var aResult = null;
	try
	{
		infoMessage(5, "db_executeStatement(): started " + sql);

		var statement = dbConnection.createStatement(sql);

		statement.executeAsync(
			{
				handleResult: 
				function(aResultSet) 
				{
					infoMessage(5, "db_executeStatement(): handleResult: " + aResultSet);
					aResult = aResultSet;
				},

				handleError: 
				function(aError) 
				{
					infoMessage(5, "db_executeStatement(): handleError: " + aError.message);
					errorMessage("Error: " + aError.message);
				},

				handleCompletion: 
				function(aReason) 
				{
					infoMessage(5, "db_executeStatement(): handleCompletion: " + aReason);
					if (aReason != Components.interfaces.mozIStorageStatementCallback.REASON_FINISHED)
					{
						errorMessage("Query canceled or aborted!");
					} else {
						if(fCompletion)
						{
							fCompletion(aResult, oResultHandle);
						}
					}					
				}
			}
		);
	}
	catch(e)
	{
		errorMessage(e);
	}
}


/*
        function Sqlite()
        {
           this.dataBaseConnection = "";
        }

        Sqlite.prototype.openDataBase = function(dataBase)
        {
           var file = Components.classes["@mozilla.org/file/directory_service;1"].getService(Components.interfaces.nsIProperties).get("ProfD", Components.interfaces.nsIFile);
           file.append(dataBase);
           
           var storageService = Components.classes["@mozilla.org/storage/service;1"].getService(Components.interfaces.mozIStorageService);
           this.dataBaseConnection = storageService.openDatabase(file);
        }

        Sqlite.prototype.retrieveData = function(query)
        {               
           var resultB = "";
           var rows = new Array(); // return ***

           if(this.dataBaseConnection != "")
           {
              var statement = this.dataBaseConnection.createStatement(query);
             
              statement.executeAsync
              ({
                 handleResult: function(aResultSet)
                 {
                    var i = 0;

        // ##########
                    //var rows = new Array(); // <-- How can I return this array? // return ***
        // ##########           

                    for (let row = aResultSet.getNextRow();   row; row = aResultSet.getNextRow())
                    {
                       rows[i] = row;
                       ++i;
                    }
                 },
                               
                 handleError: function(anError)
                 {
                    alert("error");
                 },

                 handleCompletion: function(aReason)
                 {
                    if (aReason != Components.interfaces.mozIStorageStatementCallback.REASON_FINISHED)
                         alert("error");
                 }
              });
           }
           return rows;  // return ***
        }

        var sq = new Sqlite();
        sq.openDataBase("test.sqlite");

        var result = sq.retrieveData("SELECT * FROM test");  //  returned rows ***

	    setTimeout(showResults, 0);
	   
	    function showResults() {
	        for (var j=0; j < result.length; j++) {
	             alert(result[j]);
	       }
	    }

*/

/******************************************************************************
						Common JavaScript functions - XPATH Handling
 *****************************************************************************/

function getXpathResult(document, xpath)
{
	var xpathresult = null;
	try
	{
		if(document && xpath)
		{
			infoMessage(5, "getXpathResult(): started: " + xpath);		
			xpathresult = document.evaluate(xpath, document.documentElement, null, XPathResult.ORDERED_NODE_SNAPSHOT_TYPE, null);
			infoMessage(5, "getXpathResult(): finished with snapshot items: " + xpathresult.snapshotLength);
		}	
	} catch(e) {
		errorMessage(e);
	}
	return xpathresult;
}

function getHtmlOfXpath(document, xpath, expectedNoOfResults)
{
	var sXpathresult = null;
	try
	{
		if(document && xpath)
		{
			infoMessage(5, "getHtmlOfXpath(): started: " + xpath);		
			xpathresult = document.evaluate(xpath, document.documentElement, null, XPathResult.ORDERED_NODE_SNAPSHOT_TYPE, null);			
			if(xpathresult && xpathresult.snapshotLength==1)
			{
				sXpathresult = xpathresult.snapshotItem(0).innerHTML;
				infoMessage(5, "getHtmlOfXpath(): " + sXpathresult);
			} else
			{
				errorMessage("getHtmlOfXpath(): No single XpathResult by xpath '" + xpath + "'; snapshotLength: " + xpathresult.snapshotLength);
			}
			infoMessage(5, "getHtmlOfXpath(): finished");
		}
	} catch (e) {
		errorMessage(e);
	}
	return sXpathresult;
}

function getNumberOfXpath(document, xpath, decimalPoint)
{
	var iXpathresult = null;
	try
	{
		if(document && xpath)
		{
			infoMessage(5, "getNumberOfXpath(): started: " + xpath);		
			xpathresult = document.evaluate(xpath, document.documentElement, null, XPathResult.ORDERED_NODE_SNAPSHOT_TYPE, null);			
			if(xpathresult && xpathresult.snapshotLength==1)
			{
				iXpathresult = getNumberFromNode(xpathresult.snapshotItem(0).innerHTML, decimalPoint);
				infoMessage(5, "getNumberOfXpath(): " + iXpathresult);
			} else
			{
				errorMessage("getNumberOfXpath(): No single XpathResult by xpath '" + xpath + "'; snapshotLength: " + xpathresult.snapshotLength);
			}
			infoMessage(5, "getNumberOfXpath(): finished");
		}
	} catch (e) {
		errorMessage(e);
	}
	return iXpathresult;
}

function getHrefOfXpath(document, xpath)
{
	var iXpathresult = null;
	try
	{
		if(document && xpath)
		{
			infoMessage(5, "getHrefOfXpath(): started: " + xpath);		
			xpathresult = document.evaluate(xpath, document.documentElement, null, XPathResult.ORDERED_NODE_SNAPSHOT_TYPE, null);			
			if(xpathresult && xpathresult.snapshotLength==1)
			{
				iXpathresult = xpathresult.snapshotItem(0).getAttribute('href');
				infoMessage(5, "getHrefOfXpath(): " + iXpathresult);
			} else
			{
				errorMessage("getHrefOfXpath(): No single XpathResult by xpath '" + xpath + "'; snapshotLength: " + xpathresult.snapshotLength);
			}
			infoMessage(5, "getHrefOfXpath(): finished");
		}
	} catch (e) {
		errorMessage(e);
	}
	return iXpathresult;
}

function getTableByXpath(document, xpath)
{
	var table = null;
	try
	{
		if(document && xpath)
		{
			infoMessage(5, "getTableByXpath(): started: " + xpath);		
			xpathresult = getXpathResult(document, xpath);			
			if(xpathresult && xpathresult.snapshotLength==1)
			{
				table = get1stOccurenceOfParentNode(xpathresult.snapshotItem(0), "table");		
				infoMessage(5, "getTableByXpath(): " + table);
			} else
			{
				errorMessage("getTableByXpath(): No single XpathResult by xpath '" + xpath + "'; snapshotLength: " + xpathresult.snapshotLength);
			}
			infoMessage(5, "getTableByXpath(): finished");
		}
	} catch (e) {
		errorMessage(e);
	}
	return table;
}